import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class TheWotch(BasicComicModule):
    latestUrl = 'http://www.thewotch.com/'
    imageUrl = 'http://www.thewotch.com/?epDate=%s'
    imageSearch = re.compile(r"<img.+?src='(comics/.+?)'", re.IGNORECASE)
    prevSearch = re.compile(r"<link rel='Previous' href='(\?epDate=\d+-\d+-\d+)'", re.IGNORECASE)
    help = 'Index format: yyyy-mm-dd'
